export type PersistStorageEvent<T> = (listener: (value: T) => void) => () => void;
export interface PersistStorage<T> {
    set(value: T): void;
    initialValue: T;
    defaultValue: T;
    event?: {
        root?: PersistStorageEvent<T>;
        component?: PersistStorageEvent<T>;
    };
}
export interface BrowserStorageOptions<T> {
    serialize?: (value: T) => string;
    deserialize?: (value: string | null) => T;
    initialize?: (value: T) => T;
    syncTabs?: boolean;
}
export declare function noop<T>(defaultValue: T): PersistStorage<T>;
export declare function createLocalStorage<T>(key: string, defaultValue: T, options?: BrowserStorageOptions<T>): PersistStorage<T>;
export declare function createSessionStorage<T>(key: string, defaultValue: T, options?: BrowserStorageOptions<T>): PersistStorage<T>;
export declare const rootStorageListeners: Map<string, (value: string | null) => void>;
export declare let isRootListenerEnabled: boolean;
export declare function onStorageChange(event: StorageEvent): void;
